# Supported rpmbuild --define and --with options include:
#
#   --without userland
#	Build without the userland packages
#	(i.e. only build the kernel-module packages).
#
#   --with modules
#	Force the building of a kernel-module package,
#	even if the kernel has support built in.
#
#   --without modules
#	Disable the building of a kernel-module package.
#
#   --define "ksrc <srcdir>"
#	Build with kernel header files found in <srcdir>.
#	By default, the build script will try to find the kernel headers
#	matching the specified kernel or, if no kernel was specified, the
#	current kernel.
#
#   --define "kernel <version>"
#	Specify kernel version to build the module for.
#	By default, the version is derived from the kernel source files, or
#	failing that, from "uname -r".
               

%{?ksrc: %{!?kernel: %{expand: %%define kernel %(cd "%{ksrc}" &> /dev/null && { cat Makefile 2>/dev/null && echo $'\n.PHONY: kernelhelper-rel\nkernelhelper-rel:\n\t@echo $(KERNELRELEASE)\n'; } | make -f - kernelhelper-rel 2>/dev/null || echo "custom" ) }}}
%{!?kernel: %{expand: %%define kernel %(uname -r)}}
%define fusemodule /lib/modules/%{kernel}/kernel/fs/fuse/fuse.ko

%{?_with_modules: %{?_without_modules: %{error: both _with_modules and _without_modules defined}}}
%if 0%{?_with_modules:1}
%define buildmodule 1
%else
%if 0%{?_without_modules:1}
%define buildmodule 0
%else
%{expand: %%define buildmodule %({ test -f %{fusemodule} && ! fgrep -q "fuse distribution version: " %{fusemodule}; }; echo $?)}
%endif
%endif

%if %{buildmodule}
%{!?ksrc: %{expand: %%define ksrc %(cd /lib/modules/%{kernel}/build && /bin/pwd)}}
%{!?_with_modules: %{?ksrc: %{expand: %%define buildmodule %(egrep -q "^#define CONFIG_FUSE_FS(_MODULE)? 1" %{ksrc}/include/linux/autoconf.h; echo $?)}}}
%endif

Name:           fuse
Version:        2.6.3
Release:        1%{?dist}%{!?dist:.SL}
Epoch:		5
Summary:        File System in Userspace (FUSE) utilities

Group:          System Environment/Base
License:        GPL
URL:            http://fuse.sourceforge.net/
Packager:	Paul A. Rombouts <p.a.rombouts@home.nl>
Source0:        http://dl.sourceforge.net/sourceforge/fuse/%{name}-%{version}.tar.gz
Source1:	fuse-udev.nodes
Source2:	fuse-makedev.d-fuse
Source3:	fuse-README.fedora
Source4:	fuse-README.sl

Patch0:		fuse-udev_rules.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires:	kernel >= 2.6
Requires(pre):	  %{_sbindir}/groupadd
Requires(post):   /sbin/MAKEDEV
Requires(postun): %{_sbindir}/groupdel
%if %{buildmodule}
Requires:	kernel-module-%{name} >= %{epoch}:%{version}-%{release}
%endif

%description
With FUSE it is possible to implement a fully functional filesystem in a 
userspace program. This package contains the FUSE userspace tools to 
mount a FUSE filesystem.

Note: For security reasons only members of the group "fuse" are allowed to
(u)mount fuse filesystems. You can find more details on this issue in
%{_docdir}/%{name}-%{version}/README.fedora

Additional notes for using fuse on Scientific Linux SL can be found in
README.sl.


%package libs
Summary:        File System in Userspace (FUSE) libraries
Group:          System Environment/Libraries
License:        LGPL

%description libs
With FUSE it is possible to implement a fully functional filesystem in a 
userspace program. This package contains the FUSE libraries.


%package devel
Summary:        File System in Userspace (FUSE) devel files
Group:          Development/Libraries
Requires:	%{name}-libs = %{epoch}:%{version}-%{release}
Requires: 	pkgconfig
License:        LGPL

%description devel
With FUSE it is possible to implement a fully functional filesystem in a 
userspace program. This package contains development files (headers, 
pgk-config) to develop FUSE based applications/filesystems.


%package -n kernel-module-%{name}-%{kernel}
Summary:        File System in Userspace (FUSE) kernel module
Group:          System Environment/Kernel
License:        GPL
Provides:	kernel-module-%{name} = %{epoch}:%{version}-%{release}
Requires:	/sbin/depmod
%if %{buildmodule} && 0%{!?ksrc:1}
BuildRequires:	kernel-devel = %{kernel}
%endif

%description -n kernel-module-%{name}-%{kernel}
With FUSE it is possible to implement a fully functional filesystem in a 
userspace program. This package contains the FUSE kernel module for
kernel %{kernel} and architecture %{_target_cpu}.


%prep
%setup -q
#disable device creation during build/install
sed -i.mknod 's|\<mknod\>|echo Disabled: mknod |g' util/Makefile.in
#disable depmod during kernel-module build/install
sed -i.depmod 's|\(/[a-z/]*/\)\?\<depmod\>|echo Disabled: \0 |g' kernel/Makefile.in
%patch0 -b .patch0
cp -p %{SOURCE3} README.fedora
cp -p %{SOURCE4} README.sl

%build
%configure \
%if 0%{?_without_userland:1}
 --disable-lib --disable-util --disable-example \
%endif
 --disable-static \
%if %{buildmodule}
 --enable-kernel-module %{?ksrc:--with-kernel=%{ksrc}}
%else
 --disable-kernel-module
%endif
 
make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
%if 0%{!?_without_userland:1}
find $RPM_BUILD_ROOT -type f -name "*.la" -exec rm -f {} ';'
# FIXME change from 60 to 99
install -D -p -m 644 %{SOURCE1} $RPM_BUILD_ROOT/%{_sysconfdir}/udev/makedev.d/99-fuse.nodes
install -D -p -m 644 %{SOURCE2} $RPM_BUILD_ROOT/%{_sysconfdir}/makedev.d/z-fuse
# change from 4755 to 0755 to allow stripping -- fixed later in files
chmod 0755 $RPM_BUILD_ROOT/%{_bindir}/fusermount
%else  # without userland
# Without removing these directories rpmbuild will stop and complain about unpackaged files.
rm -rf "$RPM_BUILD_ROOT/%{_includedir}" "$RPM_BUILD_ROOT/%{_libdir}"
%endif # userland

%clean
rm -rf $RPM_BUILD_ROOT

%pre 
if [ $1 -eq 1 ]; then
     %{_sbindir}/groupadd -r fuse &>/dev/null || :
fi

%post
/sbin/MAKEDEV fuse

%postun 
if [ $1 = 0 ]; then
 %{_sbindir}/groupdel fuse || :
fi

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%post -n kernel-module-%{name}-%{kernel}
if [ -f /boot/System.map-%{kernel} ]; then
        /sbin/depmod -a -F /boot/System.map-%{kernel} %{kernel} || :
else
        /sbin/depmod -a || :
fi

%postun -n kernel-module-%{name}-%{kernel}
if [ -f /boot/System.map-%{kernel} ]; then
        /sbin/depmod -a -F /boot/System.map-%{kernel} %{kernel} || :
else
        /sbin/depmod -a || :
fi

%if 0%{!?_without_userland:1}
%files
%doc AUTHORS ChangeLog COPYING FAQ Filesystems NEWS README README.NFS README.fedora README.sl
/sbin/mount.fuse
%attr(4754,root,fuse) %{_bindir}/fusermount
%{_bindir}/ulockmgr_server
%{_sysconfdir}/init.d/fuse
%{_sysconfdir}/makedev.d/z-fuse
%config %{_sysconfdir}/udev/rules.d/99-fuse.rules
%{_sysconfdir}/udev/makedev.d/99-fuse.nodes

%files libs
%doc COPYING.LIB
%{_libdir}/libfuse.so.*
%{_libdir}/libulockmgr.so.*

%files devel
%defattr(-,root,root,-)
%{_libdir}/libfuse.so
%{_libdir}/libulockmgr.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/fuse.h
%{_includedir}/ulockmgr.h
%{_includedir}/fuse
%endif # userland

%if %{buildmodule}
%files -n kernel-module-%{name}-%{kernel}
%defattr(0644,root,root,0755)
%dir /lib/modules/%{kernel}/kernel/fs/fuse
%{fusemodule}
%endif # kernel module

%changelog

* Thu Jan 22 2007 Troy Dawson <dawson@fnal.gov> - 2.6.3-1
- Updated SL version to 2.6.3,

* Mon Jan 08 2007 Paul A. Rombouts <p.a.rombouts@home.nl> - 2.6.1-1
- Updated SL version to 2.6.1-1, increased epoch number.

* Tue Dec 26 2006 Peter Lemenkov <lemenkov@gmail.com> 2.6.1-1
- Ver. 2.6.1

* Mon Nov 27 2006 Paul A. Rombouts <p.a.rombouts@home.nl> - 2.6.0-2
- Updated SL version to 2.6.0-2, increased epoch number.

* Sat Nov 25 2006 Peter Lemenkov <lemenkov@gmail.com> 2.6.0-2
- fixed nasty typo (see bug #217075)

* Fri Nov  3 2006 Peter Lemenkov <lemenkov@gmail.com> 2.6.0-1
- Ver. 2.6.0

* Sun Oct 29 2006 Peter Lemenkov <lemenkov@gmail.com> 2.5.3-5
- Fixed udev-rule again

* Sat Oct 21 2006 Paul A. Rombouts <p.a.rombouts@home.nl> - 2.5.3-4
- Updated SL version to 2.5.3-4, increased epoch number.

* Sat Oct  7 2006 Peter Lemenkov <lemenkov@gmail.com> 2.5.3-4
- Fixed udev-rule

* Tue Sep 12 2006 Peter Lemenkov <lemenkov@gmail.com> 2.5.3-3%{?dist}
- Rebuild for FC6

* Tue May 23 2006 Paul A. Rombouts <p.a.rombouts@home.nl> - 2.5.3-1
- Updated SL version to 2.5.3, increased epoch number.

* Wed May 03 2006 Peter Lemenkov <lemenkov@newmail.ru> 2.5.3-1%{?dist}
- Update to 2.5.3

* Thu Mar 30 2006 Peter Lemenkov <lemenkov@newmail.ru> 2.5.2-4%{?dist}
- rebuild

* Mon Mar 13 2006 Paul A. Rombouts <p.a.rombouts@home.nl> - 2.5.2-3
- Updated SL version to 2.5.2, increased epoch number.

* Mon Feb 13 2006 Peter Lemenkov <lemenkov@newmail.ru> - 2.5.2-3
- Proper udev rule

* Mon Feb 13 2006 Peter Lemenkov <lemenkov@newmail.ru> - 2.5.2-2
- Added missing requires

* Tue Feb 07 2006 Peter Lemenkov <lemenkov@newmail.ru> - 2.5.2-1
- Update to 2.5.2
- Dropped fuse-mount.fuse.patch

* Sat Jan 21 2006 Paul A. Rombouts <p.a.rombouts@home.nl> - 2.4.2-2
- Modified build options to match those used by rpm.livna.org.

* Wed Jan 18 2006 Paul A. Rombouts <p.a.rombouts@home.nl> - 2.4.2-2
- Renamed kernel-module package to comply with convention.
- Introduced epoch number.

* Sat Jan 14 2006 Paul A. Rombouts <p.a.rombouts@home.nl> - 2.4.2-2
- Added README.sl to the docs directory.

* Wed Jan 11 2006 Paul A. Rombouts <p.a.rombouts@home.nl> - 2.4.2-2
- Building of kernel-module package can now be specified with rpmbuild
  command-line options.
  In the default case, the kernel-module package is only built if the
  kernel does not appear to have built-in fuse support.
- In case the dist macro is undefined, .SL is used.

* Tue Jan 03 2006 Paul A. Rombouts <p.a.rombouts@home.nl> - 2.4.2-2
- Added kernel-module package

* Wed Nov 23 2005 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 2.4.2-1
- Use dist

* Wed Nov 23 2005 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 2.4.2-1
- Update to 2.4.2 (solves CVE-2005-3531)
- Update README.fedora

* Sat Nov 12 2005 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 2.4.1-3
- Add README.fedora
- Add hint to README.fedora and that you have to be member of the group "fuse"
  in the description
- Use groupadd instead of fedora-groupadd

* Fri Nov 04 2005 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 2.4.1-2
- Rename packages a bit
- use makedev.d/40-fuse.nodes
- fix /sbin/mount.fuse
- Use a fuse group to restict access to fuse-filesystems

* Fri Oct 28 2005 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 2.4.1-1
- Initial RPM release.
